# MATISS

**Marco's time saving stuff for Python**

This rapidly evolving Python package is a collection of functions and classes to aid the analysis of genomics data. It includes functions for plotting with matplotlib and seaborn, to interact with the Google Cloud Platform, for statistical testing, and others.

## Installation
Install MATISS through PIP with:
```
pip install matiss
```

## Author
Marco Teixeira \
mcarvalh@broadinstitute.org